#!/bin/bash

CURRENT_USER_APPLICATION_SUPPORT="$HOME/Library/Application Support"
JOIN_ME_APPLICATION_SUPPORT="$CURRENT_USER_APPLICATION_SUPPORT/join.me"
JOIN_ME_LAUNCHER_APP_NAME="join.me Launcher.app"
JOIN_ME_LAUNCHER_APP="$JOIN_ME_APPLICATION_SUPPORT/$JOIN_ME_LAUNCHER_APP_NAME"
JOIN_ME_LAUNCHER_NAME="join.me Launcher"

JOIN_ME_LAUNCH_AGENT_NAME="com.logmein.join.me.launcher.launchagent"
JOIN_ME_LAUNCH_AGENT_PLIST="join.me.launcher.launchagent.plist"

function log()
{
    if [ $# -le 0 ]; then
        return
    fi

    timestamp=$(date '+%Y-%m-%d %H:%M:%S')
    echo "[Launcher uninstaller] $timestamp [$$] $1"
}

function unload_from_launchctl()
{
    list=$(/bin/launchctl list | grep $JOIN_ME_LAUNCH_AGENT_NAME)
    list_size=${#list}
    if [ "$list_size" != 0 ]; then
        /bin/launchctl unload $JOIN_ME_LAUNCH_AGENT_PLIST
    fi
}

function unload_from_startup_items()
{
    list=$(/usr/bin/osascript -e 'tell application "System Events" to get the name of every login item')
    if [[ "$list" == *"$JOIN_ME_LAUNCHER_NAME"* ]]; then
        script="tell application \"System Events\" to delete login item \"${JOIN_ME_LAUNCHER_NAME}\""
        /usr/bin/osascript -e "$script"
    fi
}

function stop_running_processes()
{
    launcher_pattern="join.me.Launcher"
    running_launcher_instances=$(ps -ef | pgrep "$launcher_pattern" | wc -l)
    while [ "$running_launcher_instances" -gt 0 ]
    do
        log "$running_launcher_instances instances already running force killing..."
        launcher_pid=$(ps -ef | pgrep "$launcher_pattern")
        log "Killing $launcher_pid"
        kill -9 "$launcher_pid"
        running_launcher_instances=$(ps -ef | pgrep "$launcher_pattern" | wc -l)
    done
}

function remove_launcher()
{
    if [[ ! -d "$JOIN_ME_LAUNCHER_APP" ]]; then
        return
    fi
    log "Removing launcher from path: $JOIN_ME_LAUNCHER_APP"
    rm -rf "$JOIN_ME_LAUNCHER_APP"
}

function main()
{
    log "Unload from launchctl"
    if unload_from_launchctl; then log "Done"; else log "Failed"; fi

    log "Unload from startup items"
    if unload_from_startup_items; then log "Done"; else log "Failed"; fi

    log "Remove runnning processes"
    if stop_running_processes; then log "Done"; else log "Failed"; fi

    log "Remove launcher binary"
    if remove_launcher; then log "Done"; else log "Failed"; fi
}

log "Uninstalling join.me Launcher"
main
